@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2000-2006 Silicon Graphics, Inc.  All Rights Reserved.
 Portions Copyright 2002-2010 Sun Microsystems, Inc. All rights reserved.
-Portions Copyright 2007-2021 David Anderson. All rights reserved.
+Portions Copyright 2007-2023 David Anderson. All rights reserved.
 
 This program is free software; you can redistribute it
 and/or modify it under the terms of version 2.1 of the
@@ -26,7 +26,20 @@ Public License along with this program; if not, write the
 Free Software Foundation, Inc., 51 Franklin Street - Fifth
 Floor, Boston MA 02110-1301, USA.
 */
-/* Latest update 2021-02-23 with DW_AT_ghs_* entries. */
+
+/*! @file */
+/*! @page dwarf.h
+    dwarf.h contains all the identifiers
+    such as DW_TAG_compile_unit etc from the
+    various versions of the DWARF Standard
+    beginning with DWARF2 and containing
+    all later Dwarf Standard identifiers.
+
+    In addition, it contains all user-defined
+    identifiers that we have been able to find.
+
+    All identifiers here are C defines with the prefix "DW_" .
+*/
 
 #ifndef __DWARF_H
 #define __DWARF_H
@@ -680,7 +693,7 @@ extern "C" {
 #define DW_AT_LLVM_tag_offset                   0x3e03
 /*  LLVM intends to use 0x3e04 - 0x3e06 */
 #define DW_AT_LLVM_apinotes                     0x3e07
-/*  Next 6 are for Hetrogenous debugging */
+/*  Next 6 are for Heterogeneous debugging */
 #define DW_AT_LLVM_active_lane                  0x3e08
 #define DW_AT_LLVM_augmentation                 0x3e09
 #define DW_AT_LLVM_lanes                        0x3e0a
@@ -954,15 +967,23 @@ most-likely-useful name. */
 /* Shown here to help dwarfdump build script. */
 #define DW_ATE_ALTIUM_accum           0x81 /* ALTIUM __accum type */
 
-/* HP Floating point extensions. */
+/* HP extensions. */
 #define DW_ATE_HP_float80             0x80 /* (80 bit). HP */
-
 #define DW_ATE_HP_complex_float80     0x81 /* Complex (80 bit). HP  */
 #define DW_ATE_HP_float128            0x82 /* (128 bit). HP */
 #define DW_ATE_HP_complex_float128    0x83 /* Complex (128 bit). HP */
 #define DW_ATE_HP_floathpintel        0x84 /* (82 bit IA64). HP */
 #define DW_ATE_HP_imaginary_float80   0x85 /* HP */
 #define DW_ATE_HP_imaginary_float128  0x86 /* HP */
+#define DW_ATE_HP_VAX_float           0x88 /* F or G floating.  */
+#define DW_ATE_HP_VAX_float_d         0x89 /* D floating.  */
+#define DW_ATE_HP_packed_decimal      0x8a /* Cobol.  */
+#define DW_ATE_HP_zoned_decimal       0x8b /* Cobol.  */
+#define DW_ATE_HP_edited              0x8c /* Cobol.  */
+#define DW_ATE_HP_signed_fixed        0x8d /* Cobol.  */
+#define DW_ATE_HP_unsigned_fixed      0x8e /* Cobol.  */
+#define DW_ATE_HP_VAX_complex_float   0x8f /* ForG floating complex.*/
+#define DW_ATE_HP_VAX_complex_float_d 0x90 /* D floating complex.  */
 
 /* Sun extensions */
 #define DW_ATE_SUN_interval_float     0x91
@@ -985,7 +1006,7 @@ most-likely-useful name. */
 #define DW_IDX_GNU_internal         0x2000
 #define DW_IDX_lo_user              0x2000   /* DWARF5 */
 #define DW_IDX_GNU_external         0x2001
-#define DW_IDX_hi_user              0x0fff   /* DWARF5 */
+#define DW_IDX_hi_user              0x3fff   /* DWARF5 */
 
 /*  These with not-quite-the-same-names were used in DWARF4
     We call then DW_LLEX.
@@ -1142,11 +1163,24 @@ most-likely-useful name. */
 #define DW_LANG_Fortran08               0x0023 /* DWARF5 */
 #define DW_LANG_RenderScript            0x0024 /* DWARF5 */
 #define DW_LANG_BLISS                   0x0025 /* DWARF5 */
+#define DW_LANG_Kotlin                  0x0026 /* DWARF6 */
+#define DW_LANG_Zig                     0x0027 /* DWARF6 */
+#define DW_LANG_Crystal                 0x0028 /* DWARF6 */
+#define DW_LANG_C_plus_plus_17          0x002a /* DWARF6 */
+#define DW_LANG_C_plus_plus_20          0x002b /* DWARF6 */
+#define DW_LANG_C17                     0x002c /* DWARF6 */
+#define DW_LANG_Fortran18               0x002d /* DWARF6 */
+#define DW_LANG_Ada2005                 0x002e /* DWARF6 */
+#define DW_LANG_Ada2012                 0x002f /* DWARF6 */
+#define DW_LANG_HIP                     0x0030 /* DWARF6 */
+#define DW_LANG_Assembly                0x0031 /* DWARF6 */
+#define DW_LANG_C_sharp                 0x0032 /* DWARF6 */
+
 #define DW_LANG_lo_user                 0x8000
 #define DW_LANG_Mips_Assembler          0x8001 /* MIPS   */
 #define DW_LANG_Upc                     0x8765 /* UPC, use
                                         DW_LANG_UPC instead. */
-#define DW_LANG_GOOGLE_RenderScript     0x8001
+#define DW_LANG_GOOGLE_RenderScript     0x8e57
 /* ALTIUM extension */
 #define DW_LANG_ALTIUM_Assembler        0x9101  /* ALTIUM */
 #define DW_LANG_BORLAND_Delphi          0xb000
